voca.plugins package — voca version = release = version = release = 0.1.4 documentation

# voca.plugins package

## Submodules

## voca.plugins.basic module

`voca.plugins.basic.` `press`(chord: str)

  Press a key chord.

`voca.plugins.basic.` `send_signal`(message)

  Send a signal to a process.

`voca.plugins.basic.` `speak`(message: str)

  Speak `message` aloud.

`voca.plugins.basic.` `type_chord`(chord: str)

  Press a key chord. To avoid blocking, call this in a thread.

`voca.plugins.basic.` `write`(message: str)

  Type the `message`.

## voca.plugins.math module

## voca.plugins.no module

## voca.plugins.python module

## voca.plugins.stopstart module

## voca.plugins.terminator module

## voca.plugins.turtle_context module

## voca.plugins.yes module

## Module contents